import React from 'react';
import { QueryClient, QueryClientProvider } from 'react-query';
import { BrowserRouter as Router } from 'react-router-dom';
import { ClientContextProvider } from './context';
import ThemeProvider from './context/ThemeProvider';
import { UserStateProvider } from './context/UserContext';
import Routes from './Routes';
import { darkTheme } from './theme';

const queryClient = new QueryClient();

function App(): React.ReactElement {
  return (
    <QueryClientProvider client={queryClient}>
      <ClientContextProvider>
        <UserStateProvider>
          <ThemeProvider theme={darkTheme}>
            <Router>
              <Routes />
            </Router>
          </ThemeProvider>
        </UserStateProvider>
      </ClientContextProvider>
    </QueryClientProvider>
  );
}

export default App;
