import { Theme, useMediaQuery } from '@material-ui/core';
import React from 'react';
import styled from 'styled-components';
import DrawerMenu from '../components/DrawerMenu';
import Footer from '../components/Footer';
import Header from '../components/Header';
import MobileHeader from '../components/MobileHeader';
import { useToggle } from '../hooks/useToggle';

const Container = styled.div(
  (props) => `
  min-height: 100%;
  display: flex;
  flex-direction: column;
  justify-content: space-between;

  background-color: ${props.theme.palette.background.default};
`,
);

const MainContent = styled.div`
  height: 100%;
  flex-grow: 1;
`;

const Page: React.FC = ({ children }) => {
  const [openDrawer, { toggleOn, toggleOff }] = useToggle(false);
  const isMobile = useMediaQuery((theme: Theme) => theme.breakpoints.down('xs'));
  return (
    <Container>
      {isMobile ? (
        <MobileHeader onMenuClick={toggleOn} />
      ) : (
        <Header handleLogout={(): void => {}} />
      )}
      {isMobile && (
        <DrawerMenu open={openDrawer} toggleOpen={toggleOff} handleLogout={(): void => {}} />
      )}
      <MainContent>{children}</MainContent>
      <Footer />
    </Container>
  );
};

export default Page;
